<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Arcalapú azonosítás</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Az ellenőrzés sikeres</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Az ellenőrzés sikertelen, csak egy próbálkozása maradt</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Hitelesítés Arcalapú azonosítással</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Az Arcalapú azonosítás zárolva, kérjük használja a jelszavát</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Az eszköz nem érhető el!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Az Ön ujjlenyomatának ellenőrzése</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Az ellenőrzés sikeres</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Az ellenőrzés sikertelen, csak egy próbálkozása maradt</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Az ujjlenyomat zárolva, kérem használja a jelszavát</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Írisz Azonosítás</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Az ellenőrzés sikeres</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Az ellenőrzés sikertelen, csak egy próbálkozása maradt</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Hitelesítés Írisz Azonosítással</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Az Írisz azonosítás zárolva, kérjük használja a jelszavát</translation>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation>Kérjük csatlakoztassa a biztonsági kulcsot</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Az ellenőrzés sikeres</translation>
    </message>
    <message>
        <source>Verification failed</source>
        <translation>Az ellenőrzés sikertelen</translation>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation>A biztonsági kulcs azonosítása</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Az ellenőrzés sikeres</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Az ellenőrzés sikertelen, csak egy próbálkozása maradt</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Helytelen jelszó</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Kérjük próbálja újra 1 perc múlva</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Kérjük próbálja újra %n perc múlva</numerusform><numerusform>Kérjük próbálja újra %n perc múlva</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Jelszó visszaállítása</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Elfelejtette a jelszavát?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Kérjük próbálja újra 1 perc múlva</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Kérjük próbálja újra %n perc múlva</numerusform><numerusform>Kérjük próbálja újra %n perc múlva</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Jelszó visszaállítása</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Elfelejtette a jelszavát?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Az ellenőrzés sikeres</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform><numerusform>Az ellenőrzés sikertelen, %n próbálkozása maradt</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Az ellenőrzés sikertelen, csak egy próbálkozása maradt</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Helytelen PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey szükséges</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Adja meg a PIN kódját</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Kérjük próbálja újra %n perc múlva</numerusform><numerusform>Kérjük próbálja újra %n perc múlva</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Kérjük próbálja újra 1 perc múlva</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Kérjük próbálja újra %n perc múlva</numerusform><numerusform>Kérjük próbálja újra %n perc múlva</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Felhasználói fiók</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>A jelszava %n nap múlva lejár, kérjük változtassa meg időben</numerusform><numerusform>A jelszava %n nap múlva lejár, kérjük változtassa meg időben</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Jelszava lejárt, kérjük változtassa meg</translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation>A jelszava lejárt. A módosításhoz kérjük forduljon a Rendszergazdához.</translation>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation>A terminál zárolva van, forduljon a Rendszergazdához</translation>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Hibás Felhasználói fiók</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Helytelen jelszó</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation>A meggátolás oka:</translation>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation>Általános Mód</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Képernyő zárolása</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>A képernyő zárolása sikertelen</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Ujjlenyomat azonosítás időtúllépése, kérjük adja meg a jelszót kézzel</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Ujjlenyomatok nem egyeznek</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>A fenti felhasználók be vannak jelentkezve, ami leállításkor az adatok elvesztéséhez vezethet. Biztosan le akarja állítani?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>A fenti felhasználók be vannak jelentkezve, ami újraindításkor az adatok elvesztéséhez vezethet. Biztosan újra akarja indítani?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Engedélyezte a magas rendszer biztonsági szintet, így nem tud Wayland módra váltani. Kérjük tiltsa le a magas biztonsági szintet a Biztonsági Központban, és próbálkozzon újra.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Alvó állapot</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernálás</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zárolás</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kijelentkezés</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Felhasználóváltás</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Rendszer váltása</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Frissítés és Leállítás</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Frissítés és Újraindítás</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Rendszermonitor indítása</translation>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation>Küldje el az ellenőrző kódot</translation>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation>Kérjük adja meg a telefonszámát</translation>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation>Kérjük adja meg az ellenőrző kódot</translation>
    </message>
    <message>
        <source>获取验证码</source>
        <translation>Ellenőrző kódot kap</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation>Frissítés</translation>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation>Kérjük csatlakoztassa a számítógépet az áramforráshoz, majd telepítse a frissítéseket.</translation>
    </message>
</context>
<context>
    <name>UsersWithTheSameName</name>
    <message>
        <source>Return</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <source>Please select the account for login</source>
        <translation>Kérjük válasszon ki egy fiókot a bejelentkezéshez</translation>
    </message>
    <message>
        <source>Local Account</source>
        <translation>Helyi fiók</translation>
    </message>
    <message>
        <source>Domain Account</source>
        <translation>Tartományi fiók</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>A futó programok megakadályozzák a számítógép leállítását, és a kikapcsolás kényszerítése adatvesztést okozhat.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>A program bezárásához kattintson a Mégsem gombra, majd zárja be a programot.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>A futó programok megakadályozzák a számítógép újraindítását, és az újraindítás kényszerítése adatvesztést okozhat.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>A futó programok megakadályozzák a számítógép alvó állapotba való lépését, és az alvó állapot kényszerítése adatvesztést okozhat.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>A futó programok megakadályozzák a számítógép hibernálását, és a hibernálás kényszerítése adatvesztést okozhat.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>A futó programok megakadályozzák a számítógép kijelentkezését, és a kijelentkezés kényszerítése adatvesztést okozhat.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Újraindítás</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Alvó állapot</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernálás</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kijelentkezés</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Biztosan le akarja állítani?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Biztosan újra akarja indítani?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Biztosan ki akar jelentkezni?</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Frissítés és Leállítás</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Frissítés és Újraindítás</translation>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation>A programok bezárása és leállítás, kérjük várjon...</translation>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation>A programok bezárása és újraindítás, kérjük várjon...</translation>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation>A programok bezárása és kijelentkezés, kérjük várjon...</translation>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation>Automatikus bejelentkezés</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Bekapcsolás</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Kikapcsolás</translation>
    </message>
</context>
</TS>